/*
 * Copyright (C) 2010 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by Mikkel Kamstrup Erlandsen <mikkel.kamstrup@canonical.com>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include "zeitgeist-timestamp.h"

typedef struct
{
  
} Fixture;

static void setup    (Fixture *fix, gconstpointer data);
static void teardown (Fixture *fix, gconstpointer data);

static void
setup (Fixture *fix, gconstpointer data)
{
  
}

static void
teardown (Fixture *fix, gconstpointer data)
{
  
}

static void
test_from_iso8601 (Fixture *fix, gconstpointer data)
{
  const gchar *orig = "2010-06-17T00:00:00Z";
  gint64 from_iso = zeitgeist_timestamp_from_iso8601 (orig);
  gchar *d = zeitgeist_timestamp_to_iso8601 (from_iso);
  
  g_assert_cmpstr (orig, ==, d);
  g_free (d);
}

static void
test_inc_year (Fixture *fix, gconstpointer data)
{
  gchar *d = zeitgeist_timestamp_to_iso8601 (ZEITGEIST_TIMESTAMP_YEAR);
  
  // Since ZEITGEIST_TIMESTAMP_YEAR accounts for leap years we wont exactly
  // match "1971-01-01T00:00:00Z" on the hour
  g_assert (g_str_has_prefix (d, "1971-01-01T"));
  g_free (d);
}

static void
test_from_date (Fixture *fix, gconstpointer data)
{
  GDate date = { 0 };

  g_date_set_dmy (&date, 25, G_DATE_JUNE, 2000);
  gint64 from_date = zeitgeist_timestamp_from_date (&date);
  
  gchar *d = zeitgeist_timestamp_to_iso8601 (from_date);
  
  // Since ZEITGEIST_TIMESTAMP_YEAR accounts for leap years we wont exactly
  // match "2000-06-25T00:00:00Z" on the hour
  g_assert (g_str_has_prefix (d, "2000-06-25T"));
}

int
main (int   argc,
      char *argv[])
{
  g_type_init ();
  g_test_init (&argc, &argv, NULL);
  
  g_test_add ("/Zeitgeist/TimeRange/FromISO8601", Fixture, NULL,
              setup, test_from_iso8601, teardown);
  g_test_add ("/Zeitgeist/TimeRange/IncrementYear", Fixture, NULL,
              setup, test_inc_year, teardown);
  g_test_add ("/Zeitgeist/TimeRange/FromDate", Fixture, NULL,
              setup, test_from_date, teardown);
  
  return g_test_run();
}